import { Injectable } from '@angular/core';
import { Tarefa } from './tarefa';

@Injectable()
export class TarefaService {

  // define variavel ultimoId
  // para permitir simular incremento automatico dos ids     
  ultimoId: number = 0;

  // array de tarefas
  tarefas: Tarefa[] = [];

  constructor() { }

  // simula um POST /tarefas
  addTarefa(tarefa: Tarefa): TarefaService {
    if (!tarefa.id) {
      tarefa.id = ++this.ultimoId;
    }
    this.tarefas.push(tarefa);
    return this;
  }

  // simula um DELETE /tarefas/:id
  deleteTarefaById(id: number): TarefaService {
    this.tarefas = this.tarefas
      .filter(tarefa => tarefa.id !== id);
    return this;
  }

  // simula um  PUT /tarefas/:id
  updateTarefaById(id: number, values: Object = {}): Tarefa {
    let tarefa = this.getTarefaById(id);
    if (!tarefa) {
      return null;
    }
    Object.assign(tarefa, values);
    return tarefa;
  }

  // simula GET /tarefas
  getAllTarefas(): Tarefa[] {
    return this.tarefas;
  }

  // simula um GET /tarefas/:id
  getTarefaById(id: number): Tarefa {
    return this.tarefas
      .filter(tarefa => tarefa.id === id)
      .pop();
  }

  alternarTarefaComplete(tarefa: Tarefa){
    let updatedTarefa = this.updateTarefaById(tarefa.id, {
      concluida: !tarefa.concluida
    });
    return updatedTarefa;
  }
}

